Converting annotations to object segmentation mask images
=============================================================

.. automodule:: histomicstk.annotations_and_masks.annotations_to_object_mask_handler
    :members:
    :undoc-members:
    :show-inheritance:
